import { randomUUID } from 'node:crypto';
import path from 'node:path';
import sharp from 'sharp';
import { File } from './index.js';
class Image {
    constructor() {
        this.defaultOptions = {
            width: 100,
            height: 100,
            fit: 'contain',
            background: 'transparent',
        };
    }
    async handleImagePath() {
        const { IMAGES_PATH } = process.env;
        if (!IMAGES_PATH) {
            throw new Error('INVALID_IMAGES_PATH');
        }
        const imageDir = path.join(IMAGES_PATH, 'resized');
        const isDir = await File.isDir(imageDir);
        if (!isDir) {
            await File.createDir(imageDir);
        }
        return imageDir;
    }
    async toWebp(file, options = {}) {
        try {
            const { width, height, fit, background, } = { ...this.defaultOptions, ...options };
            const imagePath = await this.handleImagePath();
            const fileExt = file.originalname.split('.').pop();
            const parentPath = path.dirname(imagePath);
            const imageId = randomUUID();
            const fileName = `${imageId}.webp`;
            const imageFilePath = path.join(imagePath, fileName);
            const originalFile = `${imageId}.${fileExt}`;
            await new File(originalFile, parentPath).write(file.buffer);
            await sharp(file.buffer)
                .resize(width, height, { fit, background })
                .webp()
                .toFile(imageFilePath);
            return { fileName, originalFile };
        }
        catch (error) {
            console.error(error.message);
            return Promise.reject(error);
        }
    }
}
const instance = new Image();
export { instance as Image };
export default instance;
