import fs from 'fs';
import path from 'path';
import Password from './cryptPassword.js';

const backendPath = path.dirname(path.join(process.argv[1], '..'));

class BuildServerCredentials {
  defaultUser = 'teknisa';
  defaultPassword = 'teknisa';

  isDevMode() {
    const { NODE_ENV = 'development' } = process.env;
    const executionMode = ['dev', 'prod'].includes(process.argv[2]) ? process.argv[2] : null;
    return executionMode === 'dev' || (!executionMode && NODE_ENV === 'development');
  }

  writeCredentials(user, password) {
    const sourcePath = path.join(backendPath, 'server.credentials.template.json');
    const outputPath = path.join(backendPath, '.server.credentials.json');
    let fileContent = fs.readFileSync(sourcePath, { encoding: 'utf8', flag: 'r' });

    if (user && password) {
      fileContent = fileContent.replace('<>SERVER_USER<>', user);
      fileContent = fileContent.replace('<>SERVER_PASSWORD<>', Password.encrypt(password));
    }
    fs.writeFileSync(outputPath, fileContent);
  }

  build() {
    let user, password;
    if (this.isDevMode()) {
      user = this.defaultUser;
      password = this.defaultPassword;
    }
    this.writeCredentials(user, password);
  }
}

new BuildServerCredentials().build();